classdef head
    % HEAD 
    % Volume conductor interface
    %
    % Interface methods:
    % -------------------
    %
    % ############################################################## KERNEL
    % Computes kernel leadfield from dipoles to sensors
    %
    % K = kernel(obj, sensors, dipoles)
    %
    % where 
    %
    % K is a NxKx3 matrix with the kernel coefficients
    %
    % OBJ is a @vconductor object
    %
    % SENSORS is a @vxarray object with N sensor coordinates
    %
    % DIPOLES is a @diparray object with K dipole coordinates
    %
    % Note: The kernel matrix K can be used to compute the topography
    % generated by the ith dipole sensor:
    %
    % topo = squeeze(K(:,i,:))*dipole.Momemtum(i,:)'
    %
    %
    % ################################################################ PLOT
    % Plots a headmodel
    %
    % plot(obj)                    % Plot head model
    %
    %
    % % Plot a movie of topographies
    % plot(obj, 'activation', act)
    %
    % % Plot a movie of topographies in 3D
    % plot(obj, 'activation', act, '3d')
    %
    % where
    % 
    % SENSOR is a @vxarray object with sensor coordinates
    %
    % DIPOLE is a @vxarray object with dipole coordinates
    %
    % ACT is a NxT matrix with the activation of N dipoles at T time
    % instants
    %        
    %
    % 
    % #########################################################  NEW_SOURCE
    % Creates a new source within the source grid
    % 
    % obj = new_source(obj, 'key', value, ...)
    % 
    % where key/value pairs can be specific to a given headmodel. Standard
    % key/value pairs include:
    %
    % 'name'        : Source name (a string)
    %
    % 'centroid'    : Cartesian coordinates of the source centroid
    %
    % 'volume'      : Volume of the source in mm^3
    % 
    % 'minDepth'    : Minimum depth of the source voxels
    %
    % 'maxDepth'    : Maximum depth of the source voxels
    %
    % 'depth'       : Overrides minDepth and maxDepth and locate all source
    %                 voxels at the same depth
    % 
    % 'orientation' : A function handle to a orientation-generating
    %                 function. The Cartesian coordinates of each voxel
    %                 will be provided as an argument to such a function
    %
    %
    % 
    % ####################################################### DELETE_SOURCE
    %
    % obj = delete_source(obj, sourceName)
    %
    % where
    %
    % SOURCENAME is the name or the numeric index of the source to be
    % removed. 
    %
    % 
    % 
    %
    % See also: head.sphmodel, head.template

    
    methods (Abstract)
        y = kernel(obj, sensor, dipole);  
        h = plot(obj, sensor, dipole, varargin);
        obj = add_source(obj, varargin);
        obj = remove_source(obj, sourceName);
        obj = inverse_solution(obj, varargin);
        [coord, m] = get_inverse_solution_centroid(obj);
        obj = set_sensors(obj, sens);
    end
    
    
end