function obj = bcg_cca(varargin)
% BCG - Removal of BCG artifacts using CCA

import misc.process_arguments;
import pset.selector.cascade;

opt.Correction    = 70;
opt.PCAVar        = 99.9;
opt.WindowOverlap = 50;
opt.WindowLength  = 5;
[~, opt] = process_arguments(opt, varargin);

myFilter = filter.cca('MinCorr', (100-opt.Correction)/100);

myFilter = filter.sliding_window(myFilter, ...
    'WindowLength',     @(sr) opt.WindowLength*sr, ...
    'WindowOverlap',    opt.WindowOverlap);

myFilter = filter.pca(...
    'PCFilter', myFilter, ...
    'PCA',      spt.pca('RetainedVar', opt.PCAVar));


myFilter = filter.cascade(...
    myFilter, ...
    filter.tpca('Order', @(sr)) ...
    );

mySel1 = pset.selector.sensor_class('Class', {'MEG','EEG'});
mySel2 = pset.selector.good_data;

obj = meegpipe.node.filter.new(...
    'Filter',           myFilter, ...
    'DataSelector',     cascade(mySel1, mySel2), ...
    'Name',             'filter.emg', ...
    'NbChannelsReport', 0, ...
    'ShowDiffReport',   false, ...
    'IOReport',         report.plotter.io, ...
    varargin{:});

end