function obj = emg(varargin)
% EMG - Filtering EMG artifacts using CCA

import misc.process_arguments;
import pset.selector.cascade;

opt.Correction    = 70;
opt.PCAVar        = 99.9;
opt.WindowOverlap = 50;
[~, opt] = process_arguments(opt, varargin);

myCCA = spt.bss.cca('MinCorr', opt.Correction/100);
myFilter = filter.cca('CCA', myCCA);

myFilter = filter.sliding_window(myFilter, ...
    'WindowLength',     @(sr) 5*sr, ...
    'WindowOverlap',    opt.WindowOverlap);

myFilter = filter.pca(...
    'PCFilter', myFilter, ...
    'PCA',      spt.pca('RetainedVar', opt.PCAVar));

mySel1 = pset.selector.sensor_class('Class', {'MEG','EEG'});
mySel2 = pset.selector.good_data;

obj = meegpipe.node.filter.new(...
    'Filter',           myFilter, ...
    'DataSelector',     cascade(mySel1, mySel2), ...
    'Name',             'filter.emg', ...
    'NbChannelsReport', 0, ...
    'ShowDiffReport',   false, ...
    'IOReport',         report.plotter.io, ...
    varargin{:});

end