function obj = bcg_obs_ica(varargin)
% BCG_OBS_ICA - Pipeline that emulates the OBS-ICA BCG correction approach [1]
%
%
% [1] Debener et al, 2007, Neuroimage 34, 587-597.
%
% See also: meegpipe.node.pipeline

import meegpipe.node.*;

myFeat = spt.feature.topo_template.bcg;
myCrit = spt.criterion.threshold(myFeat, ...
    'MinCard',      1, ...
    'MaxCard',      1 ...
    );

icaNode =  bss.bcg(...
    'BSS',          spt.bss.jade, ...
    'RegrFilter',   filter.mlag_regr('Order', 0), ...
    'Criterion',    myCrit ...  
    );

obj  = pipeline.new('NodeList', ...
    { ...
    pipeline.basic, ...
    qrs_detect.new, ...
    obs.new, ...
    icaNode ...
    }, ...
    'Name', 'obs_ica', ...
    'Save', true, ...
    ...
    varargin{:});




end