function fileName = get_output_filename(obj, data)
% GET_OUTPUT_FILENAME - Name of the data file generated by a node
%
% fileName = get_output_filename(obj, data);
%
% Where
%
% DATA is the input to the node.
%
% FILENAME is the full path name of the data file generated by the node.
% Note that such datafile may exist only if the Save property of the node
% is set to true.
%
% See also: meegpipe.node


import meegpipe.node.globals;
import mperl.file.spec.catfile;
import exceptions.*;
import misc.var2name;
import pset.session;
import mperl.cwd.abs_path;

savePath =  globals.get.SavePath;
origFile = globals.get.OrigFile;

if isa(data, 'physioset.physioset') || ischar(data)
    
    if isempty(origFile),
        if ischar(data),
            [~, name] = fileparts(data);
        elseif ~isempty(get_name(data)),
            % IMPORTANT: This is the new way of naming the output files.
            % The name of the physioset now takes prevalence over the
            % filename. This is necessary for nodes like the bss node,
            % which may produce as output a set of independent components
            % instead of a modified version of the input physioset.
            name = get_name(data);           
        else
            [~, name] = fileparts(get_datafile(data));
        end 
    else
        [~, name] = fileparts(origFile);
    end
    
    if isempty(savePath)
        savePath = get_full_dir(obj, data);
    end
    
    objName = get_name(obj);    
    if isempty(objName),
        objName = regexprep(class(obj), '.+?\.([^\.]+)$', '$1');        
    end
    objName = strrep(objName, '_', '-');
    
    fileName = catfile(savePath, [name '_' objName pset.globals.get.HdrFileExt]);
    
else
    
    if isempty(savePath),
        savePath = get_full_dir(obj, data);
    end
    
    objName = get_name(obj);    
    if isempty(objName),
        objName = regexprep(class(obj), '.+?\.([^\.]+)$', '$1');        
    end
    objName = strrep(objName, '_', '-');
   
    fileName = catfile(savePath, ...
        [var2name(data) '_' objName globals.get.HdrFileExt]);
    
end




end