function obj = add_event_listener(obj, evGen, evType)
% add_event_listener - Add listener to events generated by other objects
%
% This is a __private__ method.
%
% ## Usage
%
% ````matlab
% add_event_listener(obj, evGen, evType);
% ````
%
% Where
%
% `obj` is a `physioset` object, `evGen` is the object generating the
% events, `evType` is the type of events to listen to. 
%
% ## Notes
%
% * Trying to add a listener to a type of event that is not recognized by
%  `physioset` objects will trigger an error. See the documentation of the 
%   [physioset class][phys-class] for more information.
%
% [phys-class]: ./README.md
%
% 
% See also: physioset.physioset, physioset.physioset.del_event_listener

if ischar(evType), evType = {evType}; end

if ~all(ismember(evType, physioset.physioset.valid_events)),
    error('physioset cannot listen to this type of events');
end

for i = 1:numel(evType),
    addlistener(evGen, evType{i}, @physioset.physioset.handle_event);
end


end