function args = construction_args(obj, type)


import exceptions.*

if nargin < 2 || isempty(type), type = 'all'; end


[weights, origWeights, physdim] = get_equalization(obj);

physiosetArgs = {...
    'SamplingRate',     obj.SamplingRate, ...
    'StartDate',        obj.StartDate, ...
    'StartTime',        obj.StartTime, ...
    'Event',            get_event(obj), ...
    'Sensors',          sensors(obj), ...
    'SamplingTime',     obj.SamplingTime, ...
    'EqWeights',        weights, ...
    'EqWeightsOrig',    origWeights, ...
    'PhysDimPrefixOrig',physdim, ...
    'BadChannel',       is_bad_channel(obj), ...
    'BadSample',        is_bad_sample(obj) ...
    };


psetArgs = {...
    'Precision',        obj.PointSet.Precision, ...
    'Writable',         obj.PointSet.Writable, ...
    'Temporary',        obj.PointSet.Temporary, ...
    'Transposed',       obj.PointSet.Transposed, ...
    'Info',             obj.PointSet.Info ...
    };

switch lower(type)
    
    case 'physioset',
        args = physiosetArgs;
        
    case 'pset',
        args = psetArgs;
        
    case 'all',
        args = [psetArgs, physiosetArgs];
        
    otherwise,
        
        throw(InvalidArgValue('type', ...
            sprintf('Unknown type ''%s''', type)));
        
end
            
    



end